@@ -3,8 +3,7 @@
 # @Time    : 2021/10/19 17:30
 # @Author  : Adyan
 # @File    : index.py
-
-
+import json
 import logging
 from flask import Flask, request, g, jsonify
 from flask_cors import CORS
@@ -52,23 +51,20 @@ def detail():
             res.set(ip, 1, ex=3)
         if int(res.get(ip)) < 2:
             # get_conn().put("ssssssss")
-            return jsonify({
-                "code": 200,
-                "data": res.srandmember(config.get("PROXY_NAME"), number=count),
-                "msg": ""
-            })
+            return json.dumps(
+                {"code": 200, "data": res.srandmember(config.get("PROXY_NAME"), number=count), "msg": ""},
+                ensure_ascii=False
+            )
         else:
-            return jsonify({
-                "code": 111,
-                "data": [],
-                "msg": "请2秒后再试"
-            })
+            return json.dumps(
+                {"code": 111, "data": [], "msg": "请2秒后再试"},
+                ensure_ascii=False
+            )
     else:
-        return jsonify({
-            "code": 112,
-            "data": [],
-            "msg": "密匙错误！！！"
-        })
+        return json.dumps(
+            {"code": 112, "data": [], "msg": "密匙错误！！！"},
+            ensure_ascii=False
+        )
 
 
 def main(host, port):
